@@ -700,17 +700,17 @@ class ANN():
     
     #util: export
     
-    def export(self, directory=r".", file_name= "model_" + str(time.localtime().tm_year) + "-" + str(time.localtime().tm_mon) + "-" + str(time.localtime().tm_mday) + "-" + str(time.localtime().tm_hour) + ":" + str(time.localtime().tm_min) + ".json", include = "all"):
+    def export(self, directory=r".", file_name= "model_" + str(time.localtime().tm_mon) + str(time.localtime().tm_mday) + "-" + str(time.localtime().tm_hour) + str(time.localtime().tm_min) + ".json", include = "all"):
 
         compat_include_params = {"all", "essential", "error_log", "gradients", "fan_io"}
 
         if not file_name.endswith(".json"):
             raise Exception("'file_name' must end with '.json'")
       
-        
+      
         if include not in compat_include_params:
 
-            if type(inlclude) == list or type(inlclude) == tuple or type(inlclude) == set:
+            if type(include) == list or type(include) == tuple or type(include) == set:
                 for param in include:
                     if param not in compat_include_params:
                         raise Exception("compatible parameters for 'include' argement are: " + str(compat_include_params))
@@ -722,25 +722,25 @@ class ANN():
         model_json = {}
 
         #essential export
+        if "all" in include or "essential" in include:
+            model_json["input_shape"] = self.input_shape
+            model_json["structure"] = self.structure
+            model_json["strict"] = self.strict
+            model_json["initializer"] = self.initializer
+            model_json["output"] = self.output
+            model_json["loss"] = self.loss
+            model_json["activations"] = self.activations
+            model_json["delta"] = self.delta
         
-        model_json["input_shape"] = self.input_shape
-        model_json["structure"] = self.structure
-        model_json["strict"] = self.strict
-        model_json["initializer"] = self.initializer
-        model_json["output"] = self.output
-        model_json["loss"] = self.loss
-        model_json["activations"] = self.activations
-        model_json["delta"] = self.delta
+            temp= []
+            for i in range(len(self.structure)):
+                temp.append(self.w_layers[i].tolist())
         
-        temp= []
-        for i in range(len(self.structure)):
-            temp.append(self.w_layers[i].tolist())
-        
-        model_json["w_layers"] = temp
-        model_json["b_layers"] = self.b_layers
+            model_json["w_layers"] = temp
+            model_json["b_layers"] = self.b_layers
         
         #optional export
-        if include == "all" or "error_log" in include:
+        if "all" in include or "error_log" in include:
 
             try:
                 model_json["error_log"] = self.error_log
@@ -748,7 +748,7 @@ class ANN():
             except Exception as e:
                 pass
 
-        if include == "all" or "gradients" in include:
+        if "all" in include or "gradients" in include:
 
             try:
                 temp=[]
@@ -770,7 +770,7 @@ class ANN():
             except Exception as e:
                 pass
         
-        if include == "all" or "fan_io" in include:
+        if "all" in include or "fan_io" in include:
         
             try:
                 temp=[]
